# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-05-25 11:10
from __future__ import unicode_literals

import django.contrib.auth.validators
from django.db import migrations, models, IntegrityError
import django.utils.timezone
import phonenumber_field.modelfields
from evoteusers.models import NO_UPN_LABEL
from contrib.adfsauth.utils import username_from_upn


def update_user(user, username):
    user.username = username
    user.save(update_fields=['username'])


def populate_username(apps, schema_editor):
    User = apps.get_model('evoteusers', 'User')
    for user in User.objects.all():
        if user.upn:
            try:
                update_user(user, username_from_upn(user.upn))
            except IntegrityError:
                update_user(user, NO_UPN_LABEL.format(user.pk))
        else:
            update_user(user, NO_UPN_LABEL.format(user.pk))


class Migration(migrations.Migration):

    dependencies = [
        ('evoteusers', '0005_user_upn'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='user',
            options={'verbose_name': 'user', 'verbose_name_plural': 'users'},
        ),
        migrations.AddField(
            model_name='user',
            name='date_joined',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='date joined'),
        ),
        migrations.AddField(
            model_name='user',
            name='first_name',
            field=models.CharField(blank=True, max_length=30, verbose_name='first name'),
        ),
        migrations.AddField(
            model_name='user',
            name='last_name',
            field=models.CharField(blank=True, max_length=30, verbose_name='last name'),
        ),
        migrations.AddField(
            model_name='user',
            name='username',
            field=models.CharField(blank=True, error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username'),
        ),
        migrations.RunPython(populate_username, reverse_code=migrations.RunPython.noop),
        migrations.AlterField(
            model_name='user',
            name='username',
            field=models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.ASCIIUsernameValidator()], verbose_name='username'),
        ),
        migrations.AlterField(
            model_name='user',
            name='email',
            field=models.EmailField(blank=True, db_index=True, max_length=254, verbose_name='predefined email address'),
        ),
        migrations.AlterField(
            model_name='user',
            name='nic',
            field=models.CharField(max_length=64, verbose_name='citizen card number'),
        ),
        migrations.AlterField(
            model_name='user',
            name='upn',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='user personnel number'),
        ),
        migrations.AlterField(
            model_name='user',
            name='is_active',
            field=models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active'),
        ),
        migrations.AlterField(
            model_name='user',
            name='is_staff',
            field=models.BooleanField(default=False, help_text='Designates whether the user can log into this admin site.', verbose_name='staff status'),
        ),
        migrations.AlterField(
            model_name='user',
            name='primary_phone',
            field=phonenumber_field.modelfields.PhoneNumberField(blank=True, max_length=128, verbose_name='predefined mobile number'),
        ),
    ]
